@@ -6,11 +6,21 @@ use base qw(DateTime::Format::Natural::Base);
 
 use Carp qw(croak);
 use DateTime ();
-use Date::Calc qw(Day_of_Week);
+use Date::Calc qw(Day_of_Week check_date);
 use List::MoreUtils qw(all any);
 use Params::Validate ':all';
 
-our $VERSION = '0.70';
+our $VERSION = '0.72';
+
+validation_options(
+    on_fail => sub
+{
+    my ($error) = @_;
+    chomp $error;
+    croak $error;
+},
+    stack_skip => 2,
+);
 
 sub new
 {
@@ -45,16 +55,6 @@ sub _init_check
 {
     my $self = shift;
 
-    validation_options(
-        on_fail => sub
-    {
-        my ($error) = @_;
-        chomp $error;
-        croak $error;
-    },
-        stack_skip => 2,
-    );
-
     validate(@_, {
         lang => {
             type => SCALAR,
@@ -150,6 +150,7 @@ sub parse_datetime
         my ($day, $month, $year) = map { $bits[$separated_indices->{$_}] } qw(d m y);
 
         if (not defined $day && defined $month && defined $year) {
+            $self->_set_failure;
             $self->_set_error("('format' parameter invalid)");
             return $self->_get_datetime_object;
         }
@@ -157,9 +158,8 @@ sub parse_datetime
         if ($year > $century) { $century-- };
         if (length $year == 2) { $year = "$century$year" };
 
-        if (not $self->SUPER::_valid_date(day => $day)
-             && $self->SUPER::_valid_date(month => $month)
-             && $self->SUPER::_valid_date(year => $year)) {
+        unless (check_date($year, $month, $day)) {
+            $self->_set_failure;
             $self->_set_error("(invalid date)");
             return $self->_get_datetime_object;
         }
@@ -193,13 +193,13 @@ sub _parse_init
     my $self = shift;
 
     if (@_ > 1) {
-        validate(@_, { string => 1 });
+        validate(@_, { string => { type => SCALAR }});
         my %opts             = @_;
         $self->{Date_string} = $opts{string};
         (undef)              = $opts{debug}; # legacy
     }
     else {
-        validate_pos(@_, 1);
+        validate_pos(@_, { type => SCALAR });
         ($self->{Date_string}) = @_;
     }
 
@@ -596,6 +596,7 @@ valuable suggestions & patches:
  Jonny Schulz
  Jesse Vincent
  Jason May
+ Pat Kale
 
 =head1 SEE ALSO
 
